@@ -1,7 +1,7 @@
 from .assets import Asset, PowerGeneratingAsset
 from .calculation import calculate_impacts
 from .curve import ExceedanceCurve
-from .events import Drought, Event, RiverineInundation
 from .hazard_event_distrib import HazardEventDistrib
+from .hazards import Drought, Hazard, RiverineInundation
 from .vulnerability_distrib import VulnerabilityDistrib
-from .vulnerability_model import VulnerabilityModelBase
+from .vulnerability_model import VulnerabilityModelAcuteBase
